@@ -19,7 +19,7 @@ import os.path
 class EndOfLineComment(str):
     pass
 
-sched_version = "4" # version of SCHED VEX writing routine
+sched_version = "5" # version of SCHED VEX writing routine
 
 block_separator = "*------------------------------------------------------"\
                   "------------------------\n"
@@ -394,9 +394,11 @@ def modes_block(vex_version, print_warnings):
         if track_format is None:
             return None, None, None
         
-        def datastream_for_channels(datastream_link, channel_links):
+        def datastream_for_channels(datastream_label, channel_links):
+            datastream_link = "&" + datastream_label
             thread_link = "&thread0"
-            datastream = (("datastream", datastream_link, "VDIF"),
+            datastream = (("datastream",
+                           datastream_link, "VDIF", datastream_label),
                           ("thread", 
                            datastream_link, 
                            thread_link, 
@@ -429,12 +431,12 @@ def modes_block(vex_version, print_warnings):
             
             datastream = ()
             for index, if_ in enumerate(sorted(used_ifs), 1):
-                datastream_link = "&DS{}".format(index)
+                datastream_label = "DS{}".format(index) 
                 channel_links = [
                     freq[index][5] # FREQ link name
                     for index, channel in enumerate(channel_order)
                     if channel.ifchan == if_]
-                datastream += datastream_for_channels(datastream_link, 
+                datastream += datastream_for_channels(datastream_label,
                                                       channel_links)
             return None, datastream, None
 
@@ -456,10 +458,10 @@ def modes_block(vex_version, print_warnings):
                 
         if track_format.startswith("VDIF"):
             # hard-coded 1 thread VDIF section, with astro patching
-            datastream_link = "&DS1"
+            datastream_label = "DS1"
             channel_links = [freq[channel[3]][5] for channel in channel_order
                              if channel[2] == "sign"]
-            datastream = datastream_for_channels(datastream_link, 
+            datastream = datastream_for_channels(datastream_label, 
                                                  channel_links)
                                                  
             return None, datastream, None
@@ -849,8 +851,12 @@ def modes_block(vex_version, print_warnings):
         modes_text += """
 *
 def {};
+""".format(mode_name)[1:]
+        if vex_version < "2":
+            modes_text += """
      ref $PROCEDURES = Procedure:{};
-""".format(mode_name, ":".join(station.stcode for station in stations))[1:]
+""".format(":".join(station.stcode for station in stations))[1:]
+        
         # go through all block in order
         for block in blocks:
             if block not in mode.keys():
@@ -898,6 +904,8 @@ def {};
     return (modes_text, scan_mode_name)
 
 def procedures_block(vex_version):
+    if vex_version >= "2":
+        return ""
     # just a hardcoded procedure
     return """
 $PROCEDURES;
@@ -1131,10 +1139,11 @@ def pointing_sectors(station, vex_version, print_warnings):
                      for zone in zones)
     else:
         # VEX 2 added a zone name
-        return tuple(("pointing_sector", zone[0], 
+        return tuple(("pointing_sector", 
                       "&" + zone[0] + name_suffix(zone),
                       "az", deg.format(zone[1]), deg.format(zone[2]),
-                      "el", deg.format(zone[3]), deg.format(zone[4])) 
+                      "el", deg.format(zone[3]), deg.format(zone[4]),
+                      zone[0]) 
                      for zone in zones)
 
 def scan_sector(station, scan, az1, el1):
